@@ -8,7 +8,7 @@ import json
 import sqlite3
 import multiprocessing
 from typing import Any, List
-from . import lib, cursor, search
+from . import lib, cursor, query
 
 
 def _to_json(data:dict) -> str:
@@ -80,14 +80,14 @@ def _parse_smart_filtering(filters: dict, indexed_columns:list=[]) -> dict:
     sql_filters = []
     json_filters = {}
     for k, v in filters.items():
-        if search.FILTER_OPERATOR in k:
-            f, op = k.split(search.FILTER_OPERATOR)
-            if f in indexed_columns and op in search.SQL_OPERATORS:
-                sql_filters.append((f, search.SQL_OPERATORS[op], v))
+        if query.FILTER_OPERATOR in k:
+            f, op = k.split(query.FILTER_OPERATOR)
+            if f in indexed_columns and op in query.SQL_OPERATORS:
+                sql_filters.append((f, query.SQL_OPERATORS[op], v))
                 continue
         else:
             if k in indexed_columns:
-                sql_filters.append((k, search.SQL_OPERATORS["eq"], v))
+                sql_filters.append((k, query.SQL_OPERATORS["eq"], v))
                 continue
         json_filters[k] = v
               
@@ -280,8 +280,7 @@ class Collection(object):
     """
     ::Collection
     """
-    # Column you can't query
-    NON_QUERYABLE_COLUMNS = ["_json"]
+
     DEFAULT_COLUMNS = ["_id", "_json", "_created_at", "_modified_at"]
     _columns = []
     _indexes = []
@@ -340,7 +339,6 @@ class Collection(object):
                         f = _i2.fetchone()
                         indexes.append(f["name"])
                     self._indexes = indexes
-                    #return [item.keys() for item in _exec]
                 except: pass
         return self._indexes
 
@@ -557,7 +555,7 @@ class Collection(object):
                 chunked = _exec.fetchmany(chunk)
                 if chunked:
                     rows = [_row_to_dict(row) for row in chunked]
-                    for r in search.execute(rows, smart_filters["JSON_FILTERS"]):
+                    for r in query.execute(rows, smart_filters["JSON_FILTERS"]):
                         data.append(r)
                 else:
                     break
